Index: trunk/ppTranslate/src/ppMops.h
===================================================================
--- trunk/ppTranslate/src/ppMops.h	(revision 28623)
+++ trunk/ppTranslate/src/ppMops.h	(revision 29556)
@@ -13,19 +13,20 @@
 // Configuration data
 typedef struct {
-    psArray *input;                     // Input filenames
-    psString exp_name;                  // Exposure name
-    psS64 exp_id;                       // Exposure identifier
-    psS64 chip_id;                      // Chip stage identifier
-    psS64 cam_id;                       // Camera stage identifier
-    psS64 fake_id;                      // Fake stage identifier
-    psS64 warp_id;                      // Warp stage identifier
-    psS64 diff_id;                      // Diff stage identifier
-    bool positive;                      // Sense of subtraction, T=positive, F=negative
-    float zp, zpErr;                    // Magnitude zero point and error
-    float rmsAstrom;                    // Astrometric solution RMS
-    psString output;                    // Output filename
+  psArray *input;                     // Input filenames
+  psString exp_name;                  // Exposure name
+  psS64 exp_id;                       // Exposure identifier
+  psS64 chip_id;                      // Chip stage identifier
+  psS64 cam_id;                       // Camera stage identifier
+  psS64 fake_id;                      // Fake stage identifier
+  psS64 warp_id;                      // Warp stage identifier
+  psS64 diff_id;                      // Diff stage identifier
+  bool positive;                      // Sense of subtraction, T=positive, F=negative
+  float zp, zpErr;                    // Magnitude zero point and error
+  float rmsAstrom;                    // Astrometric solution RMS
+  psString output;                    // Output filename
 } ppMopsArguments;
 
 #if 0
+#warning "IS THERE ANYTHING TO BE MODIFIED HERE?"
 TTYPE19 = 'PSF_CHISQ'          / label for field  19
 TFORM19 = '1E      '           / data format of field: 4-byte REAL
@@ -58,33 +59,59 @@
 
 typedef struct {
-    psString raBoresight, decBoresight; // RA,Dec of telescope boresight
-    psString filter;                    // Filter for exposure
-    float airmass;                      // Airmass of exposure
-    float exptime;                      // Exposure time
-    double posangle;                    // Position angle
-    double alt, az;                     // Telescope altitude and azimuth
-    double mjd;                         // Modified Julian Date
-    float seeing;                       // Seeing of exposure
-    long num;                           // Number of detections
-    psVector *x, *y;                    // Image coordinates
-    psVector *ra, *dec;                 // Sky coordinates
-    psVector *raErr, *decErr;           // Error in sky coordinates
-    psVector *mag, *magErr;             // Magnitude and associated error
-    psVector *chi2, *dof;               // Chi^2 from fitting, with associated degrees of freedom
-    psVector *cr, *extended;            // Measures of CR-ness and extendedness
-    psVector *psfMajor, *psfMinor, *psfTheta; // PSF major and minor axes, and position angle
-    psVector *quality, *numPix;               // PSF quality factor and number of pixels
-    psVector *xxMoment, *xyMoment, *yyMoment; // Moments
-    psVector *flags;                    // psphot flags
-    psVector *diffSkyfileId;            // Identifier for source image
-    psVector *naxis1, *naxis2;          // Size of image
-    psVector *mask;                     // Mask for detections
-    psVector *nPos;                     // Number of positive pixels
-    psVector *fPos;                     // Fraction of positive flux
-    psVector *nRatioBad;                // Fraction of positive pixels to negative
-    psVector *nRatioMask;               // Fraction of positive pixels to masked
-    psVector *nRatioAll;                // Fraction of positive pixels to all
+  psString raBoresight, decBoresight; // RA,Dec of telescope boresight
+  psString filter;                    // Filter for exposure
+  float airmass;                      // Airmass of exposure
+  float exptime;                      // Exposure time
+  double posangle;                    // Position angle
+  double alt, az;                     // Telescope altitude and azimuth
+  double mjd;                         // Modified Julian Date
+  float seeing;                       // Seeing of exposure
+  long num;                           // Number of detections
+  psVector *x, *y;                    // Image coordinates
+  psVector *ra, *dec;                 // Sky coordinates
+  psVector *raErr, *decErr;           // Error in sky coordinates
+  psVector *mag, *magErr;             // Magnitude and associated error
+  psVector *chi2, *dof;               // Chi^2 from fitting, with associated degrees of freedom
+  psVector *cr, *extended;            // Measures of CR-ness and extendedness
+  psVector *psfMajor, *psfMinor, *psfTheta; // PSF major and minor axes, and position angle
+  psVector *quality, *numPix;               // PSF quality factor and number of pixels
+  psVector *xxMoment, *xyMoment, *yyMoment; // Moments
+  psVector *flags;                    // psphot flags
+  psVector *diffSkyfileId;            // Identifier for source image
+  psVector *naxis1, *naxis2;          // Size of image
+  psVector *mask;                     // Mask for detections
+  psVector *nPos;                     // Number of positive pixels
+  psVector *fPos;                     // Fraction of positive flux
+  psVector *nRatioBad;                // Fraction of positive pixels to negative
+  psVector *nRatioMask;               // Fraction of positive pixels to masked
+  psVector *nRatioAll;                // Fraction of positive pixels to all
+  psVector *psfInstFlux;              // PSF fit instrumental magnitude
+  psVector *psfInstFluxSig;           // Sigma of PSF instrumental magnitude
+  psVector *apMag;                    // Magnitude in standard aperture
+  psVector *apMagRadius;              // Radius used for aperture mags
+  psVector *apMagRaw;                 // Magnitude in real aperture
+  psVector *apFlux;                   // Instrumental flux in standard aperture
+  psVector *apFluxSig;                // Aperture flux error
+  psVector *peakFluxAsMag;            // Peak flux expressed as magnitude
+  psVector *calPsfMag;                // PSF Magnitude using supplied calibration
+  psVector *calPsfMagSig;             // Measured scatter of zero point calibration
+  psVector *sky;                      // Sky level
+  psVector *skySig;                   // Sigma of sky level
+  psVector *qualityPerfect;           // PSF coverage/quality factor (poor)
+  psVector *momentsR1;                // First radial moment
+  psVector *momentsRH;                // Half radial moment
+  psVector *kronFlux;                 // Kron Flux (in 2.5 R1)
+  psVector *kronFluxErr;              // Kron Flux Error
+  psVector *kronFluxInner;            // Kron Flux (in 1.0 R1)
+  psVector *kronFluxOuter;            // Kron Flux (in 4.0 R1)
+  psVector *diffRP;                   // Distance to positive match source
+  psVector *diffSnP;                  // Signal-to-noise of pos match src
+  psVector *diffRM;                   // Distance to negative match source
+  psVector *diffSnM;                  // Signal-to-noise of neg match src
+  psVector *flags2;                   // psphot flags (group 2)
+  psVector *ippIdet;                  // IPP detection identifier index
+  psVector *nFrames;                  // Number of frames overlapping source center
+  psVector *padding;                  // Padding
 } ppMopsDetections;
-
 
 ppMopsDetections *ppMopsDetectionsAlloc(long num);
@@ -95,5 +122,4 @@
 /// Purge the detections list of masked detections
 bool ppMopsDetectionsPurge(ppMopsDetections *detections);
-
 
 /// Read detections
